@@ -6,16 +6,16 @@ from nbconvert import HTMLExporter
 import pymbse.commons.json_file as json_file
 import pymbse.commons.text_file as text_file
 
-IMPORT_KEYWORD = 'import'
-FROM_KEYWORD = 'from'
-PARAMETERS_KEYWORD = 'parameters'
-TAGS_KEYWORD = 'tags'
-METADATA_CELL_KEYWORD = 'metadata'
-SB_GLUE_OUTPUT_KEYWORD = 'sb.glue'
-SOURCE_CELL_KEYWORD = 'source'
-CODE_KEYWORD = 'code'
-CELLS_KEYWORD = 'cells'
-CELL_TYPE_KEYWORD = 'cell_type'
+IMPORT_KEYWORD = "import"
+FROM_KEYWORD = "from"
+PARAMETERS_KEYWORD = "parameters"
+TAGS_KEYWORD = "tags"
+METADATA_CELL_KEYWORD = "metadata"
+SB_GLUE_OUTPUT_KEYWORD = "sb.glue"
+SOURCE_CELL_KEYWORD = "source"
+CODE_KEYWORD = "code"
+CELLS_KEYWORD = "cells"
+CELL_TYPE_KEYWORD = "cell_type"
 
 
 def convert_ipynb_to_html(ipynb_abs_path: str, html_abs_path: str) -> None:
@@ -28,19 +28,19 @@ def convert_ipynb_to_html(ipynb_abs_path: str, html_abs_path: str) -> None:
         nb = nbformat.read(f, as_version=4)
 
     config = {
-        'TemplateExporter': {'exclude_input': True},
-        'TagRemovePreprocessor': {'remove_all_outputs_tags': ["skip_output"]}
+        "TemplateExporter": {"exclude_input": True},
+        "TagRemovePreprocessor": {"remove_all_outputs_tags": ["skip_output"]},
     }
     html_exporter = HTMLExporter(config)
     body, _ = html_exporter.from_notebook_node(nb)
     decoded_body = body.encode("ascii", "ignore").decode()
-    with open(html_abs_path, 'w') as f:
+    with open(html_abs_path, "w") as f:
         f.write(decoded_body)
 
 
-def create_script_if_missing_or_outdated(notebook_abs_path: str,
-                                         script_abs_path: str,
-                                         model_name_without_ext: str) -> None:
+def create_script_if_missing_or_outdated(
+    notebook_abs_path: str, script_abs_path: str, model_name_without_ext: str
+) -> None:
     """Function creating a script from a notebook if the script is either missing or outdated (notebook was updated
     after the script creation).
 
@@ -49,7 +49,9 @@ def create_script_if_missing_or_outdated(notebook_abs_path: str,
     :param model_name_without_ext: name of a model without an extension
     """
     if is_script_missing_or_outdated(notebook_abs_path, script_abs_path):
-        convert_notebook_to_script(notebook_abs_path, model_name_without_ext, script_abs_path)
+        convert_notebook_to_script(
+            notebook_abs_path, model_name_without_ext, script_abs_path
+        )
 
 
 def is_script_missing_or_outdated(notebook_abs_path: str, script_abs_path: str) -> bool:
@@ -90,8 +92,10 @@ def is_script_outdated(notebook_abs_path: str, script_abs_path: str) -> bool:
     return model_last_modification_time > script_last_modification_time
 
 
-def convert_notebook_to_script(notebook_abs_path: str, notebook_name: str, script_abs_path: str) -> None:
-    """ Function converting a notebook into a script equivalent. The notebook is executed as a function.
+def convert_notebook_to_script(
+    notebook_abs_path: str, notebook_name: str, script_abs_path: str
+) -> None:
+    """Function converting a notebook into a script equivalent. The notebook is executed as a function.
     The function name is given by as run_<notebook_name>. The input arguments are taken from cells with `parameters`
     tags. The return value is taken from the sb.glue code.
 
@@ -101,22 +105,24 @@ def convert_notebook_to_script(notebook_abs_path: str, notebook_name: str, scrip
     """
     # Parse notebook
     notebook = json_file.read(notebook_abs_path)
-    cells_with_parameters, cells_with_code = separate_parameters_and_code_cells(notebook)
+    cells_with_parameters, cells_with_code = separate_parameters_and_code_cells(
+        notebook
+    )
     parameter_lines = extract_parameter_lines(cells_with_parameters)
     code_lines = extract_code_lines(cells_with_code)
     output_variable = extract_output_variable(cells_with_code)
     cleaned_code_lines = remove_ipython_magic_and_sys_path_apppend(code_lines)
 
     # Construct script
-    function_parameters = ', '.join(parameter_lines)
+    function_parameters = ", ".join(parameter_lines)
     output_lines = []
-    output_lines.append('\n')
-    output_lines.append('def run_%s_script(%s):' % (notebook_name, function_parameters))
+    output_lines.append("\n")
+    output_lines.append("def run_%s_script(%s):" % (notebook_name, function_parameters))
 
     for cleaned_code_line in cleaned_code_lines:
-        output_lines.append('\t' + cleaned_code_line)
+        output_lines.append("\t" + cleaned_code_line)
 
-    output_lines.append('\t' + 'return ' + output_variable)
+    output_lines.append("\t" + "return " + output_variable)
 
     text_file.writelines(script_abs_path, output_lines)
 
@@ -127,13 +133,18 @@ def separate_parameters_and_code_cells(notebook: dict) -> tuple:
     :param notebook: a dictionary witho notebook contents
     :return: a two-element tuple containing a list of cells with parameters and list of cells with code
     """
-    cells_with_all_code = [cell for cell in notebook[CELLS_KEYWORD] if cell[CELL_TYPE_KEYWORD] == CODE_KEYWORD]
+    cells_with_all_code = [
+        cell
+        for cell in notebook[CELLS_KEYWORD]
+        if cell[CELL_TYPE_KEYWORD] == CODE_KEYWORD
+    ]
     cells_with_parameters = []
     cells_with_code = []
 
     for cell in cells_with_all_code:
         if TAGS_KEYWORD in cell[METADATA_CELL_KEYWORD] and (
-                PARAMETERS_KEYWORD in cell[METADATA_CELL_KEYWORD][TAGS_KEYWORD]):
+            PARAMETERS_KEYWORD in cell[METADATA_CELL_KEYWORD][TAGS_KEYWORD]
+        ):
             cells_with_parameters.append(cell)
         else:
             cells_with_code.append(cell)
@@ -151,9 +162,11 @@ def extract_parameter_lines(cells_with_parameters: list) -> list:
     parameters = []
     for cell in cells_with_parameters:
         for line in cell[SOURCE_CELL_KEYWORD]:
-            if '#' in line:
-                raise AttributeError('No commented lines are allowed in the Input Parameters cell!')
-            parameters.append(line.replace('\n', ''))
+            if "#" in line:
+                raise AttributeError(
+                    "No commented lines are allowed in the Input Parameters cell!"
+                )
+            parameters.append(line.replace("\n", ""))
 
     return parameters
 
@@ -168,7 +181,7 @@ def extract_code_lines(cells_with_code: list) -> list:
     for cell in cells_with_code:
         for line in cell[SOURCE_CELL_KEYWORD]:
             if SB_GLUE_OUTPUT_KEYWORD not in line:
-                code_lines.append(line.replace('\n', ''))
+                code_lines.append(line.replace("\n", ""))
     return code_lines
 
 
@@ -178,15 +191,15 @@ def extract_output_variable(cells_with_code: list) -> str:
     :param cells_with_code: a list of cells with code
     :return: an output variable name
     """
-    output_line = ''
+    output_line = ""
     for cell in cells_with_code:
         for line in cell[SOURCE_CELL_KEYWORD]:
             if SB_GLUE_OUTPUT_KEYWORD in line:
                 output_line = line
 
-    output_variable = output_line.split(',')[1]
-    if '=' in output_variable:
-        output_variable = output_variable.split('=')[-1]
+    output_variable = output_line.split(",")[1]
+    if "=" in output_variable:
+        output_variable = output_variable.split("=")[-1]
 
     return output_variable
 
@@ -200,7 +213,7 @@ def remove_ipython_magic_and_sys_path_apppend(code_lines: list) -> list:
     cleaned_code_lines = []
 
     for code_line in code_lines:
-        if not (code_line.startswith('%') or ('sys.path.append' in code_line)):
+        if not (code_line.startswith("%") or ("sys.path.append" in code_line)):
             cleaned_code_lines.append(code_line)
 
     return cleaned_code_lines
