@@ -21,7 +21,9 @@ class ModelAPI(BaseModel, ABC):
     def get_artefact(self, artefact_name: str) -> str:
         model_snapshot = self.execute()
         if artefact_name not in model_snapshot.artefacts:
-            print('An artefact %s is missing. Returning an empty string.' % artefact_name)
+            print(
+                "An artefact %s is missing. Returning an empty string." % artefact_name
+            )
             return ""
 
         return model_snapshot.artefacts[artefact_name]
